using Elwig.Models;
using System.Collections.Generic;
using System.Threading.Tasks;

namespace Elwig.Helpers.Export {
    /// <summary>
    /// Interface for exporting banking data
    /// </summary>
    public interface IBankingProvider {
        /// <summary>
        /// The default file extension of the exported files to be used (whithout a preceding ".")
        /// </summary>
        string FileExtension { get; }

        /// <summary>
        /// Export the member payment data of the given payment variant to the given file.
        /// (The amount of the last payed variant is deducted from the calculated amount.)
        /// </summary>
        /// <param name="filename">The file to export the data to</param>
        /// <param name="avnr">The number of the payment variant to export</param>
        /// <param name="members">The members whose data to include in the export</param>
        Task Export(string filename, int avnr, IEnumerable<Member> members);
    }
}
